==> tintii_2.6.1.orig.tar.gz: tintii-2.6.1/src/indii/tint/model/ClusterModelObservable.hpp <==
/**
 * Copyright (C) 2007-2012 Lawrence Murray
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * @author Lawrence Murray <lawrence@indii.org>
 * $Rev: 363 $
 * $Date: 2012-01-22 18:45:43 +0800 (Sun, 22 Jan 2012) $
 */
#ifndef INDII_TINT_MODEL_CLUSTERMODELOBSERVABLE_HPP
#define INDII_TINT_MODEL_CLUSTERMODELOBSERVABLE_HPP

#include <set>

namespace indii {
  class ClusterModelObserver;

/**
 * Observable object.
 */
class ClusterModelObservable {
public:
  /**
   * Destructor.
   */
  virtual ~ClusterModelObservable();

  /**
   * Registry type.
   */
  typedef std::set<ClusterModelObserver*> registry_t;

  /**
   * Register observer.
   */
  void subscribe(ClusterModelObserver* o);

  /**
   * Deregister observer.
   */
  void unsubscribe(ClusterModelObserver* o);

  /**
   * Notify change specific to a single cluster.
   *
   * @param i The cluster.
   */
  virtual void notifyClusterChange(const unsigned i);

  /**
   * Notify change of hue rotation to a single cluster.
   *
   * @param i The cluster.
   */
  virtual void notifyHueChange(const unsigned i);

  /**
   * Notify change of saturation adjustent to a single cluster.
   *
   * @param i The cluster.
   */
  virtual void notifySatChange(const unsigned i);

  /**
   * Notify change of lightness adjustment to a single cluster.
   *
   * @param i The cluster.
   */
  virtual void notifyLightChange(const unsigned i);

  /**
   * Notify change in number of clusters.
   */
  virtual void notifyNumClustersChange();

  /**
   * Notify change in hard/soft cluster assignment.
   */
  virtual void notifyIsHardChange();

  /**
   * Notify change in number of repetitions.
   */
  virtual void notifyNumRepetitionsChange();

  /**
   * Notify change in saturation threshold.
   */
  virtual void notifySaturationThresholdChange();

  /**
   * Notify change in maximum pixels for clustering.
   */
  virtual void notifyMaxPixelsChange();

  /**
   * Notify change in saturation decay.
   */
  virtual void notifySaturationDecayChange();

  /**
   * Notify change in centroid decay.
   */
  virtual void notifyCentroidDecayChange();

  /**
   * Notify change in saturation softness.
   */
  virtual void notifySaturationSoftnessChange();

  /**
   * Notify change in centroid softness.
   */
  virtual void notifyCentroidSoftnessChange();

  /**
   * Notify destruction.
   */
  virtual void notifyDestroy();

protected:
  /**
   * Registry of observers.
   */
  registry_t os;
};
}

#endif

==> tintii_2.7.0.orig.tar.gz: tintii-2.7.0/src/indii/tint/model/ClusterModelObservable.hpp <==
/**
 * Copyright (C) 2007-2013 Lawrence Murray
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * @author Lawrence Murray <lawrence@indii.org>
 * $Rev: 500 $
 * $Date: 2013-08-16 19:04:13 +0800 (Fri, 16 Aug 2013) $
 */
#ifndef INDII_TINT_MODEL_CLUSTERMODELOBSERVABLE_HPP
#define INDII_TINT_MODEL_CLUSTERMODELOBSERVABLE_HPP

#include <set>

namespace indii {
  class ClusterModelObserver;

/**
 * Observable object.
 */
class ClusterModelObservable {
public:
  /**
   * Destructor.
   */
  virtual ~ClusterModelObservable();

  /**
   * Registry type.
   */
  typedef std::set<ClusterModelObserver*> registry_t;

  /**
   * Register observer.
   */
  void subscribe(ClusterModelObserver* o);

  /**
   * Deregister observer.
   */
  void unsubscribe(ClusterModelObserver* o);

  /**
   * Notify change specific to a single cluster.
   *
   * @param i The cluster.
   */
  virtual void notifyClusterChange(const unsigned i);

  /**
   * Notify change of hue rotation to a single cluster.
   *
   * @param i The cluster.
   */
  virtual void notifyHueChange(const unsigned i);

  /**
   * Notify change of saturation adjustent to a single cluster.
   *
   * @param i The cluster.
   */
  virtual void notifySatChange(const unsigned i);

  /**
   * Notify change of lightness adjustment to a single cluster.
   *
   * @param i The cluster.
   */
  virtual void notifyLightChange(const unsigned i);

  /**
   * Notify change of alpha adjustment to a single cluster.
   *
   * @param i The cluster.
   */
  virtual void notifyAlphaChange(const unsigned i);

  /**
   * Notify change in number of clusters.
   */
  virtual void notifyNumClustersChange();

  /**
   * Notify change in hard/soft cluster assignment.
   */
  virtual void notifyIsHardChange();

  /**
   * Notify change in number of repetitions.
   */
  virtual void notifyNumRepetitionsChange();

  /**
   * Notify change in saturation threshold.
   */
  virtual void notifySaturationThresholdChange();

  /**
   * Notify change in maximum pixels for clustering.
   */
  virtual void notifyMaxPixelsChange();

  /**
   * Notify change in saturation decay.
   */
  virtual void notifySaturationDecayChange();

  /**
   * Notify change in centroid decay.
   */
  virtual void notifyCentroidDecayChange();

  /**
   * Notify change in saturation softness.
   */
  virtual void notifySaturationSoftnessChange();

  /**
   * Notify change in centroid softness.
   */
  virtual void notifyCentroidSoftnessChange();

  /**
   * Notify destruction.
   */
  virtual void notifyDestroy();

protected:
  /**
   * Registry of observers.
   */
  registry_t os;
};
}

#endif
